@@ -17,15 +17,16 @@
 
 from warnings import warn
 from pyspark import keyword_only
-from ai.h2o.sparkling.Initializer import Initializer
+from ai.h2o.sparkling import Initializer
 from ai.h2o.sparkling.ml.Utils import Utils
-from ai.h2o.sparkling.ml.algos.H2OSupervisedAlgorithmWithFoldColumn import H2OSupervisedAlgorithmWithFoldColumn
+from ai.h2o.sparkling.ml.algos.H2OSupervisedAlgorithm import H2OSupervisedAlgorithm
 from ai.h2o.sparkling.ml.models.H2OGAMMOJOModel import H2OGAMMOJOModel
 from ai.h2o.sparkling.ml.params.H2OGAMParams import H2OGAMParams
+from ai.h2o.sparkling.ml.params.H2OCommonParams import H2OCommonParams
 from ai.h2o.sparkling.ml.algos.FamilyBasedH2OTrainFramePreparation import FamilyBasedH2OTrainFramePreparation
 
 
-class H2OGAM(H2OGAMParams, H2OSupervisedAlgorithmWithFoldColumn, FamilyBasedH2OTrainFramePreparation):
+class H2OGAM(H2OGAMParams, H2OCommonParams, H2OSupervisedAlgorithm, FamilyBasedH2OTrainFramePreparation):
 
     @keyword_only
     def __init__(self,
@@ -33,9 +34,7 @@ class H2OGAM(H2OGAMParams, H2OSupervisedAlgorithmWithFoldColumn, FamilyBasedH2OT
                  betaConstraints=None,
                  gamCols=None,
                  columnsToCategorical=[],
-                 keepBinaryModels=False,
                  withContributions=False,
-                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
@@ -46,6 +45,7 @@ class H2OGAM(H2OGAMParams, H2OSupervisedAlgorithmWithFoldColumn, FamilyBasedH2OT
                  convertUnknownCategoricalLevelsToNa=False,
                  splitRatio=1.0,
                  withStageResults=False,
+                 withDetailedPredictionCol=True,
                  seed=-1,
                  family="AUTO",
                  tweedieVariancePower=0.0,
@@ -54,7 +54,6 @@ class H2OGAM(H2OGAMParams, H2OSupervisedAlgorithmWithFoldColumn, FamilyBasedH2OT
                  solver="AUTO",
                  alphaValue=None,
                  lambdaValue=None,
-                 startval=None,
                  lambdaSearch=False,
                  earlyStopping=True,
                  nlambdas=-1,
@@ -79,12 +78,9 @@ class H2OGAM(H2OGAMParams, H2OSupervisedAlgorithmWithFoldColumn, FamilyBasedH2OT
                  computePValues=False,
                  removeCollinearCols=False,
                  numKnots=None,
-                 splineOrders=None,
                  scale=None,
                  bs=None,
                  keepGamCols=False,
-                 standardizeTpGamCols=False,
-                 scaleTpPenaltyMat=False,
                  knotIds=None,
                  modelId=None,
                  nfolds=0,
@@ -103,14 +99,12 @@ class H2OGAM(H2OGAMParams, H2OSupervisedAlgorithmWithFoldColumn, FamilyBasedH2OT
                  stoppingMetric="AUTO",
                  stoppingTolerance=0.001,
                  customMetricFunc=None,
-                 exportCheckpointsDir=None,
-                 aucType="AUTO"):
+                 exportCheckpointsDir=None):
         Initializer.load_sparkling_jar()
         super(H2OGAM, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.H2OGAM", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
-        kwargs = self._updateInitKwargs(kwargs)
 
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
