@@ -17,7 +17,7 @@
 
 from warnings import warn
 from pyspark import keyword_only
-from ai.h2o.sparkling.Initializer import Initializer
+from ai.h2o.sparkling import Initializer
 from ai.h2o.sparkling.ml.Utils import Utils
 from ai.h2o.sparkling.ml.algos.H2OGLM import H2OGLM
 
@@ -32,9 +32,7 @@ class H2OGLMRegressor(H2OGLM):
                  betaConstraints=None,
                  interactionPairs=None,
                  columnsToCategorical=[],
-                 keepBinaryModels=False,
                  withContributions=False,
-                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
@@ -45,6 +43,7 @@ class H2OGLMRegressor(H2OGLM):
                  convertUnknownCategoricalLevelsToNa=False,
                  splitRatio=1.0,
                  withStageResults=False,
+                 withDetailedPredictionCol=True,
                  seed=-1,
                  family="AUTO",
                  randomFamily=None,
@@ -83,7 +82,6 @@ class H2OGLMRegressor(H2OGLM):
                  maxConfusionMatrixSize=20,
                  computePValues=False,
                  removeCollinearCols=False,
-                 generateScoringHistory=False,
                  modelId=None,
                  nfolds=0,
                  keepCrossValidationModels=True,
@@ -96,21 +94,21 @@ class H2OGLMRegressor(H2OGLM):
                  foldAssignment="AUTO",
                  ignoreConstCols=True,
                  scoreEachIteration=False,
-                 checkpoint=None,
                  stoppingRounds=0,
                  maxRuntimeSecs=0.0,
                  stoppingMetric="AUTO",
                  stoppingTolerance=0.001,
                  customMetricFunc=None,
                  exportCheckpointsDir=None,
-                 aucType="AUTO"):
+                 **kwargs):
         Initializer.load_sparkling_jar()
         super(H2OGLM, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.regression.H2OGLMRegressor", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
-        kwargs = self._updateInitKwargs(kwargs)
-
+        if 'distribution' in kwargs:
+            del kwargs['distribution']
+            warn("The parameter 'distribution' is deprecated and will be removed in the version 3.34.")
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
         self._set(**kwargs)
